Glossary

# XMLRésuméLibrary: User Guide

CSS Class Reference | XML Résumé Library User Guide | Part III. Appendixes

## Glossary

attribute

  Attributes provide additional information about element that they appear in. They take the form of name-value pairs in the element. The emphasized parts of this example are attributes:

      <author name="a.kernighan">
      <resume id="r25a4">

element

  An element of an XML document that defines an “object”, such as `<resume>` or `<firstname>`. HTML tags are examples of elements. Additionally, elements can have attributes. Elements have a start (or "open") tag (e.g., `<firstname>`) and an end (or "close") tag (e.g., `</firstname>`).

  Each element (except for the root `<resume>`) has exactly one parent element and 0 or more child elements.

parent element

  The element whose start tags and end tags surround a given element.

child element

  Any element positioned between the start tags and end tags of a given element.

CSS Class Reference | XML Résumé Library User Guide | Part III. Appendixes